@@ -25,7 +25,7 @@ class Repository:
         host = self.config.get(section='DATABASE', key='host')
         port = self.config.get(section='DATABASE', key='port')
         database = self.config.get(section='DATABASE', key='database')
-        self.engine = create_engine(f'mysql+pymysql://{username}:{password}@{host}:{port}/{database}', echo=is_debug) # , isolation_level='READ UNCOMMITTED')
+        self.engine = create_engine(f'mysql+pymysql://{username}:{password}@{host}:{port}/{database}?auth_plugin=mysql_native_password', echo=is_debug) # , isolation_level='READ UNCOMMITTED')
         Session = sessionmaker(bind=self.engine)
         self.session = scoped_session(Session)
   
